@@ -15,14 +15,14 @@ An Perl implementation of the same credential abstraction is available
 in CPAN:
 http://search.cpan.org/~lcons/Authen-Credential/
 
-Copyright (C) 2012 CERN
+Copyright (C) 2013 CERN
 """
 AUTHOR = "Massimo Paladin <massimo.paladin@gmail.com>"
-COPYRIGHT = "Copyright (C) 2012 CERN"
-VERSION = "0.6"
-DATE = "17 Apr 2012"
+COPYRIGHT = "Copyright (C) 2013 CERN"
+VERSION = "1.0"
+DATE = "4 Mar 2013"
 __author__ = AUTHOR
 __version__ = VERSION
 __date__ = DATE
 
-from auth.credential.credential import new, parse, Credential
\ No newline at end of file
+from auth.credential.credential import new, parse, Credential
