@@ -1,7 +1,7 @@
 """
  Testing package for auth.credential
- 
- Copyright (C) 2012 CERN
+
+ Copyright (C) 2013 CERN
 """
 
 import os
@@ -9,4 +9,4 @@ import sys
 
 sys.path.insert(0, os.path.split(__file__)[0])
 
-__all__ = [  ]
+__all__ = list()
